
###############################################################################################
#  AN EXAMPLE TO FIT THE GRADED RESPONSE MODEL:   Classical Inference                         #                                       
#                                                                                             #
# Data contain answers of 333 respondent to 4 items of the scale of attitudes toward Mobile   #
# mobil banking of Puschel, Mazzon e Hernandez (2010).                                        #
# Data are described in Bazán J., Merino, M. H. and Mazzon, J. A. (2011).                     #
# Classificação de modelos de resposta ao item policotômicos com aplicação ao marketing.      #
# Revista Brasileira de Estatística, 72, 7-39.                                                #
#                                                                                             #
###############################################################################################



# install package ltm, psych, foreign
#install.packages(c("ltm","psych","foreign") 

#1. Read data

require(foreign)  
#wd="C:\\Users\\Jorge Luis\\Copy\\MinicursTRI\\Exemplos\\Graded"
#setwd(wd)
setwd(dirname(rstudioapi::getActiveDocumentContext()$path))

attitude<- read.spss(file="No usuarios - Atitude2.sav", use.value.labels=TRUE, 
max.value.labels=Inf,to.data.frame = TRUE)


#2. Classical item analysis 
require(ltm)
cronbach.alpha(attitude)

require(psych)
alpha(attitude)


#3.Evaluation of multidimensionality

fa(attitude)  #factor analysis using pearson correlation matrix

require(psych)
c=polychoric(attitude)

fap <- fa(r=c$rho)  #factor analysis using polychoric correlation matrix
fap

par(mfrow=c(1,2))
fa.diagram(fap,cut=0.4)
factor.plot(fap,cut=0.4,ylim=c(0,1),xlim=c(0,5))
abline(h=0.4,col=4,lty=2)

##########################################################################
#4. ML Estimation of Graded response model using ltm: Calibration of items
#with usual parameterization

require(ltm)
fitGRM=grm(attitude)

fitGRM
summary(fitGRM)


#help(grm)
#5. Report of results

#Area under the Test or Item Information Curves, can be considered some items
information(fitGRM,  c(-4,  4))

#ploteos
opar=par(mfrow = c(2, 2))
plot(fitGRM, lwd = 2, legend = TRUE, ncol = 2)


## Item Information Curves for the Atitude data;
plot(fitGRM, type = "IIC", legend = TRUE, cx = "topright", lwd = 2, cex = 1.4)


#6. ML estimation of abilities with item parameters knowns
require(ltm)

detach("package:psych", unload=TRUE)

fscEAP=factor.scores(fitGRM,method="EAP")
fscEAP

 
trait<-fscEAP$score.dat$z1
par(mfrow=c(1,1))
hist(trait,xlim=c(-3,3))


#########################################################################################

#6. ML Estimation of Graded response model using mirt: Calibration of items
#with usual parameterization

  require(mirt)
fitgrm <- mirt(attitude, 1, 'graded',
               removeEmptyRows = TRUE, quadpts = 100)
aa = coef(fitgrm, simplify=TRUE,IRTpars = TRUE)
res = aa$items
res
fitgrm

#7. ML estimation of abilities with item parameters knowns
scoresest <- fscores(fitgrm, method="EAP", response.pattern =
                       attitude)
summary(scoresest)
est_scores <- as.data.frame(scoresest)
summary(est_scores)

#8. Report of results
trait <- est_scores$F1
summary(trait)
length(trait)
par(mfrow=c(1,1))
hist(trait, xlim=c(-4,4),
     ylim = c(0,250),
     main="",
     xlab = "Traços",
     ylab = "Frequência")

library(readxl)
library(writexl)

# Cálculo do T Score para os traços
Tscore=trait*10+50
summary(Tscore)
hist(Tscore,
     xlim = c(10,80),
     ylim = c(0, 250),
     xlab = "T Score",
     ylab = "Frequência",
     main = "")
T_score <- as.data.frame(Tscore)
write_xlsx(x = T_score, path = "T_score.xlsx", col_names = TRUE)
summary(fitgrm)
summary(aa)
length(scoresest)

# Note. Reviewed your results with carefully  Compare your results with the obtained 
# using other software. For example you can use IRTPRO
# http://www.ssicentral.com/irt/student.html

# Homework. Compare results from ltm and mirt